rm(list=ls())

###########################
### DATA DOWNLOADED FROM https://www.psmsl.org/data/obtaining/stations/540.php
### FORMAT DESCRIBED AT https://www.psmsl.org/data/obtaining/notes.php
###
### The monthly files list the date (year-month in decimal form), mean sea level value for the month, number of missing days of data in the month, and 'flag for attention'. The Fortran fixed format for reading this data is 1x,f10.4,1x,i6,1x,i2,1x,i3. The year-month decimal form is given by year + (month-0.5)/12.0 thereby centering the monthly mean essentially in the middle of the calendar month in question. The monthly mean values are in mm.
###########################

lplotfile     = FALSE

station.num   = 540  #  APRA HARBOR GUAM
station       = 'Guam'
season        = 'JFM'
dir.data      = "/Users/delsole/SMCS_data/"
dir.Rlib      = '/Users/delsole/SMCS_function_exercises/'
iyst          = 1973
iynd          = 2006

#########################################
## CHECK IF DATA DIRECTORY EXISTS.  IF NOT, SEND ERROR MESSAGE
#########################################
if (!dir.exists(dir.data)) {
	print('#### DATA DIRECTORY DOES NOT EXIST ON YOUR SYSTEM #################')
	print('#### CHANGE dir.data TO THE DIRECTORY CONTAINING YOUR DATA FILES')
	print('#### IF DATA IS IN THE SAME DIRECTORY AS THIS CODE (not recommended), SET dir.data = NULL')
	stop()	
}
if (!dir.exists(dir.Rlib)) {
	print('#### DATA DIRECTORY DOES NOT EXIST ON YOUR SYSTEM #################')
	print('#### CHANGE dir.Rlib TO THE DIRECTORY CONTAINING YOUR DATA FILES')
	print('#### IF DATA IS IN THE SAME DIRECTORY AS THIS CODE, SET dir.Rlib = NULL')
	stop()	
}


#######################################################
########### METADATA
#######################################################
nyrs   = iynd - iyst + 1
x.year = iyst:iynd

source(paste(dir.Rlib,'pdf.eps.R',sep=''))
source(paste(dir.Rlib,'enso.index.v2.R',sep=''))
if (season == 'OND') {
	month.season = c(10,11,12)
} else if (season == 'JFM') {
	month.season = c(1,2,3)
} else stop('do not understand season')


#######################################################
########### READ SST SL DATA 
#######################################################
fwidths       = c(1,10,1,6,1,2,1,3)
indices.fname = paste(dir.data,station.num,'.rlrdata',sep='')
indices.all   = read.fwf(indices.fname,widths=fwidths)

missing       = indices.all[,4] == -99999
indices.all[missing,4] = NA


#######################################################
########### DEFINE THE SEA LEVEL DATA
#######################################################
year    = floor(indices.all[,2])
month   = round((indices.all[,2] - year)*12 + 0.5)
iyst.sl = min(year)
iynd.sl = max(year)
ntot    = length(month)

if ( !all(month = rep(1:12,ceiling(ntot/12))[1:ntot])) stop('months not consecutive')
if ( !all(year  = rep(iyst.sl:iynd.sl,each=12)[1:ntot])) stop('years not consecutive')

y  = as.numeric(rep(NA,nyrs))
for (ny in 1:nyrs) {
	year.pic = iyst + ny - 1
	npic     = rep(FALSE,ntot)
	for (m in 1:length(month.season)) npic = npic | (year == year.pic & month == month.season[m])
	y[ny] = mean(indices.all[npic,4],na.rm=TRUE)
}

#######################################################
########### FILL IN MISSING USING LINEAR INTEPOLATION 
#######################################################
missing = which(is.na(y))
y[missing] = (y[missing+1] + y[missing-1])/2
if (any(is.na(y))) stop('missing data exists')

#######################################################
########### DEFINE SST DATA
#######################################################
x.sst = numeric(nyrs)
for (m in 1:length(month.season)) x.sst = x.sst + enso.index.v2(iyst,iynd,month.season[m])
x.sst = x.sst / length(month.season)

#######################################################
########### DEFINE SST DATA
#######################################################
par(mfcol=c(2,1),mar=c(5,5,3,1))
plot(x.year,y,type='b',pch=19,ylab='sea level (mm)')
ftitle = paste('Guam Sea Level (mm) During',season)
title(main=ftitle)

plot(x.year,x.sst,type='b',pch=19,ylab='NINO3.4')
ftitle = paste('NINO3.4')
title(main=ftitle)

#######################################################
#### AT THIS POINT, THE FOLLOWING VARIABLES ARE DEFINED:
#### SEASON: CHARACTER DESCRIBING THE SEASON (E.G., 'OND' FOR 'OCT-NOV-DEC')
#### IYST: START YEAR
#### IYND: END YEAR
#### NYRS: TOTAL NUMBER OF YEARS
#### Y[NYRS]: GUAM SEA LEVEL (mm) AVERAGED OVER THE SEASON
#### X.YEAR[NYRS]: YEAR 
#### X.SST[NYRS]: NINO3.4 INDEX FOR THE SAME YEAR/SEASON
#######################################################

#######################################################
######## PLOT DATA 
#######################################################
fout = paste('sealevel',station,season,'pdf',sep='.')
if (lplotfile) pdf(fout,height=4,width=8.5)
par(mfcol=c(1,1))
par(mar=c(5,5,3,1))
par(cex.lab=1.5,cex.axis=1.5,cex.main=1.5)
plot(x.year,y,type='b',pch=19,lwd=2,xlab='year',ylab='sea level (mm)')
ftitle = paste(station,'Sea Level During',season)
title(main=ftitle,line=0.5)
abline(lm(y~x.year),lty='dashed',lwd=3,col='grey50')
if (lplotfile) dev.off()



